@@ -30,17 +30,11 @@ describe 'basic neutron' do
 
       # Neutron resources
       class { '::neutron':
-        rabbit_user           => 'neutron',
-        rabbit_password       => 'an_even_bigger_secret',
-        rabbit_host           => '127.0.0.1',
+        default_transport_url => 'rabbit://neutron:an_even_bigger_secret@127.0.0.1:5672/',
         allow_overlapping_ips => true,
         core_plugin           => 'ml2',
         debug                 => true,
-        service_plugins => [
-          'neutron.services.l3_router.l3_router_plugin.L3RouterPlugin',
-          'neutron_lbaas.services.loadbalancer.plugin.LoadBalancerPlugin',
-          'neutron.services.metering.metering_plugin.MeteringPlugin',
-        ],
+        service_plugins       => ['router', 'metering'],
       }
       class { '::neutron::db::mysql':
         password => 'a_big_secret',
@@ -51,15 +45,16 @@ describe 'basic neutron' do
       class { '::neutron::plugins::ml2':
         type_drivers         => ['vxlan'],
         tenant_network_types => ['vxlan'],
-        mechanism_drivers    => ['openvswitch', 'sriovnicswitch']
+        mechanism_drivers    => ['openvswitch'],
+      }
+      class { '::neutron::keystone::authtoken':
+        password            => 'a_big_secret',
       }
       class { '::neutron::server':
         database_connection => 'mysql+pymysql://neutron:a_big_secret@127.0.0.1/neutron?charset=utf8',
-        auth_password       => 'a_big_secret',
-        identity_uri        => 'http://127.0.0.1:35357/',
         sync_db             => true,
         service_providers   => [
-          'LOADBALANCER:Haproxy:neutron_lbaas.services.loadbalancer.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default',
+          'LOADBALANCERV2:Haproxy:neutron_lbaas.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver'
         ],
       }
       class { '::neutron::client': }
@@ -71,11 +66,16 @@ describe 'basic neutron' do
       }
       class { '::neutron::agents::metering': debug => true }
       class { '::neutron::agents::ml2::ovs':
-        enable_tunneling => true,
         local_ip         => '127.0.0.1',
-        tunnel_types => ['vxlan'],
+        tunnel_types     => ['vxlan'],
+        # Prior to Newton, the neutron-openvswitch-agent used 'ovs-ofctl' of_interface driver by default.
+        # In Newton, 'of_interface' defaults to 'native'.
+        # This mostly eliminates spawning ovs-ofctl and improves performance a little.
+        # Current openstack-selinux does not allow the Ryu controller to listen on 6633 port.
+        # So in the meantime, let's use old interface:
+        of_interface     => 'ovs-ofctl',
+        ovsdb_interface  => 'vsctl',
       }
-      class { '::neutron::agents::ml2::sriov': }
       class { '::neutron::services::lbaas::haproxy': }
       class { '::neutron::services::lbaas::octavia': }
       EOS
