@@ -7,7 +7,10 @@ require 'spec_helper'
 describe 'neutron::plugins::ml2::cisco::ucsm' do
 
   let :pre_condition do
-    "class { 'neutron::server': auth_password => 'password'}
+    "class { '::neutron::keystone::authtoken':
+      password => 'passw0rd',
+     }
+     class { 'neutron::server': }
      class { 'neutron':
       rabbit_password => 'passw0rd',
       core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
