@@ -3,7 +3,10 @@ require 'spec_helper'
 describe 'neutron::plugins::ml2::ovn' do
 
   let :pre_condition do
-    "class { 'neutron::server': password => 'password' }
+    "class { '::neutron::keystone::authtoken':
+      password => 'passw0rd',
+     }
+     class { 'neutron::server': }
      class { 'neutron': rabbit_password => 'passw0rd' }"
   end
 
